@@ -5,12 +5,14 @@ package Lemonldap::NG::Handler::Server::Main;
 
 use strict;
 
-our $VERSION = '2.0.10';
+our $VERSION = '2.19.0';
 
 use base 'Lemonldap::NG::Handler::PSGI::Main';
 
 use constant defaultLogger => 'Lemonldap::NG::Common::Logger::Syslog';
 
+$ENV{LLNG_DEFAULTLOGGER} ||= defaultLogger;
+
 # In server mode, headers are not passed to a PSGI application but returned
 # to the server
 
@@ -34,9 +36,22 @@ sub unset_header_in {
     my $i = $req->data->{deleteIndex};
     foreach my $header (@headers) {
         $class->logger->debug("Delete header $header");
-        $req->{respHeaders} =
-          [ grep { $_ ne $header and $_ ne cgiName($header) }
-              @{ $req->{respHeaders} } ];
+        my $del = 0;
+        $req->{respHeaders} = [
+            map {
+                my @res;
+                if ($del) {
+                    $del = 0;
+                }
+                elsif ( $_ and ( $_ eq $header or $_ eq cgiName($header) ) ) {
+                    $del = 1;
+                }
+                else {
+                    @res = ($_);
+                }
+                @res;
+            } @{ $req->{respHeaders} }
+        ];
         delete $req->{env}->{ cgiName($header) };
         push @{ $req->{respHeaders} }, "Deleteheader$i", $header;
         $i++;
